// main.cc
//
//    guitune(gtk--) - program for tuning instruments
//                     (actually an oscilloscope)
//    Copyright (C) 1999  Florian Berger
//    Email: florian.berger@jk.uni-linz.ac.at
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License Version 2 as
//    published by the Free Software Foundation;
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//

#include <gtk--/window.h>
#include <gtk--/menubar.h>
#include <gtk--/menu.h>
#include <gtk--/main.h>
#include <gtk--/box.h>

#include "guitune.h"

using SigC::slot;
using SigC::bind;


void destroy_cb(void)
{
    Gtk::Main::quit();
}


int main(int argc, char *argv[])
{
    Gtk::Main kit(argc, argv);
    
    MainWidget m_wid;
    m_wid.set_usize( 380, 220 );
    
    Gtk::MenuBar  *  menubar = manage( new Gtk::MenuBar());
    
    // Activate the helpers for easy menu setup.
    {
        using namespace Gtk;
        using namespace Menu_Helpers;

        // Create the file menu
        Menu    * menu_file     = manage( new Menu());
        MenuList& list_file     = menu_file->items();
        list_file.push_back(MenuElem("_Quit", "<control>q", slot(destroy_cb)));
                                           // ^^^^^^^^^^^^

        // submenu tuning
        Menu *menu_tuning = manage( new Menu());
        MenuList& list_tuning = menu_tuning->items();
        RadioMenuItem::Group gr3;
        list_tuning.push_back(RadioMenuElem( gr3,"_Normal",
                    slot(&m_wid, &MainWidget::setTuningNorm) ));
        list_tuning.push_back(RadioMenuElem( gr3,"_Wien",
                    slot(&m_wid, &MainWidget::setTuningWien) ));
        list_tuning.push_back(RadioMenuElem( gr3,"_Physical",
                    slot(&m_wid, &MainWidget::setTuningPhys) ));
        list_tuning.push_back(SeparatorElem());
        RadioMenuItem::Group gr2;
        list_tuning.push_back(RadioMenuElem( gr2,"_Equidistant",
                    slot(&m_wid, &MainWidget::setTuningEqui) ));
        list_tuning.push_back(RadioMenuElem( gr2,"N_atural",
                    slot(&m_wid, &MainWidget::setTuningNat) ));
        

        // submenu scale
        Menu *menu_scale = manage( new Menu());
        MenuList& list_scale = menu_scale->items();
        RadioMenuItem::Group gr1;
        list_scale.push_back(RadioMenuElem( gr1,"_US",
                   slot(&m_wid, &MainWidget::setScaleUS) ));
        list_scale.push_back(RadioMenuElem( gr1,"US-_Alt",
                   slot(&m_wid, &MainWidget::setScaleUSAlt) ));
        list_scale.push_back(RadioMenuElem( gr1,"_German",
                   slot(&m_wid, &MainWidget::setScaleGE) ));
        list_scale.push_back(RadioMenuElem( gr1,"G_erman-Alt",
                   slot(&m_wid, &MainWidget::setScaleGEAlt) ));


        // Create the options menu
        Menu *menu_options  = manage( new Menu());
        MenuList& list_opt = menu_options->items();
        list_opt.push_back(MenuElem( "_Tuning"            , *menu_tuning ));
        list_opt.push_back(MenuElem( "Note _Scale"        , *menu_scale  ));


        // Create the help menu
//        Menu    *menu_help                = manage( new Menu());
//        menu_help->items().push_back(MenuElem("About", slot(void_void_cb)));


        // Create the menu bar
        //   Gtk+ does not have O(1) tail lookups so you should build menus
        //   backwards whenever you plan to make lots of access to back().
        MenuList& list_bar = menubar->items();
//        list_bar.push_front(MenuElem("_Help","<control>h",*menu_help));
//        list_bar.front()->right_justify();
        menubar->items().push_front(MenuElem("_Options","<control>o",*menu_options));
        menubar->items().push_front(MenuElem("_File","<control>f",*menu_file));
    }

    
    Gtk::VBox *vbox = manage( new Gtk::VBox() );
    vbox->pack_start (*menubar, false, false);
    vbox->pack_start ( m_wid,   true,  true );

    
//    Gtk::Window window (GTK_WINDOW_TOPLEVEL);
//    window.show();
    
    Gtk::Window win (GTK_WINDOW_TOPLEVEL);

    win.add(*vbox);
    win.set_default_size( 500, 240 );
    
    win.show_all();
    
//    Gtk::Main::idle.connect(  slot( &m_wid, &MainWidget::proc_audio )  );
    
    kit.run();  // you will need to ^C to exit.
    
    return(0);
}
